@@ -21,7 +21,7 @@ from overrides import overrides
 from torch.nn.modules import Linear, Dropout
 from transformers import AutoModel
 
-from srl_transformers.utils import load_lemma_frame, load_role_frame
+from transformer_srl.utils import load_lemma_frame, load_role_frame
 
 LEMMA_FRAME_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "lemma2frame.csv"
 FRAME_ROLE_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "frame2role.csv"
